==> nui_media-0.0.19.tar.gz: lib/ui/nui_imageview_picker.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_media/nui_media.dart';

typedef ImageSelectListener = void Function(NUIMediaFile file);

class NUIImageViewStyle{
  NUIImageViewStyle({this.elevation, this.shadowColor, this.outlineThickness, this.outlineColor, this.backgroundColor, this.radius, this.placeHolder, this.errorHolder, this.fit, this.rippleColor});
  double elevation;
  Color shadowColor;
  double outlineThickness;
  Color outlineColor;
  double radius;
  Color backgroundColor;
  Color rippleColor;
  Widget placeHolder;
  Widget errorHolder;
  BoxFit fit = BoxFit.cover;

}

class NUIImageViewPicker extends StatefulWidget {
  NUIImageViewPicker({this.path, @required this.width, @required this.height, this.isLocal:true, this.style, this.selectionOption: MediaSelectionOption.GALLERY, this.enabled: true, this.listener, Key key}): super(key: key);
  final String path;
  final bool isLocal;
  final double width;
  final double height;
  final bool enabled;
  final MediaSelectionOption selectionOption;
  final NUIImageViewStyle style;
  final ImageSelectListener listener;
  @override
  _NUIImageViewPickerState createState() => _NUIImageViewPickerState();
}

class _NUIImageViewPickerState extends State<NUIImageViewPicker> {
  String imagePath;
  NUIMediaFile imageFile;

  @override
  void initState(){
    super.initState();
    this.imagePath = widget.path;
  }

  double _getInnerHeight(){
    return widget.height - ((widget.style?.outlineThickness ?? 0)*2);
  }

  double _getInnerWidth(){
    return widget.width - ((widget.style?.outlineThickness ?? 0)*2);
  }

  Widget _getDefaultPlaceHolder(){
    return Center(
        child: Padding(
          padding: const EdgeInsets.all(5.0),
          child: Text("Click here", style: TextStyle(color: NUIColors.NUITextGray, fontSize: 12), textAlign: TextAlign.center),
        )
    );
  }

  Widget _getImageView(){
    if(isNullOrEmpty(imagePath) && imageFile == null){
      return widget.style?.placeHolder ?? _getDefaultPlaceHolder();
    }
    else{
      if(widget.isLocal || imageFile != null){
        return loadImageLocal(imageFile?.path ?? widget.path, _getInnerWidth(), _getInnerHeight());
      }
      else{
        return loadImage(widget.path, width: _getInnerWidth(), height: _getInnerHeight());
      }
    }
  }

  void selectImage(){
    if(!widget.enabled) return;

    NUIBottomSheet dialog;
    dialog = NUIMediaUtil.showMediaSelection(context, enableGallery: widget.selectionOption == MediaSelectionOption.GALLERY || widget.selectionOption == MediaSelectionOption.BOTH, enableCamera: widget.selectionOption == MediaSelectionOption.CAMERA || widget.selectionOption == MediaSelectionOption.BOTH, enableRecord: false, listener: (files){
      if(!isNullOrEmpty(files)){
        //An image has been selected either via camera or gallery
        setState(() {
          this.imageFile = files[0];
          if(widget.listener != null){
            widget.listener(this.imageFile);
            dialog.dismiss((){
            });
          }
        });
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    Widget content = NUIClipView(
      borderRadius: BorderRadius.circular(widget.style?.radius ?? 10),
      child: Container(
        height: _getInnerHeight(),
        width: _getInnerWidth(),
        color: widget.style?.backgroundColor ?? NUIColors.NUISkeletalLightGray,
        child: NUIRippleContainer(
          child: _getImageView(),
          radius: widget.style.radius ?? 10,
          borderRadius: BorderRadius.circular(widget.style?.radius ?? 10),
          normalColor: NUIColors.NUITransparent,
          rippleColor: widget.enabled ? (widget.style?.rippleColor ?? NUIColors.NUIBlack.withOpacity(0.2)) : NUIColors.NUITransparent,
          onTap: (){
            selectImage();
          },
        ),
      ),
    );

    if(widget.style?.outlineThickness != null && widget.style.outlineThickness > 0){
      return Container(
        height: widget.height,
        width: widget.width,
        alignment: Alignment.center,
        child: content,
        decoration: NUIBoxDecoration(
          shadowRadius: widget.style?.elevation ?? 0,
          shadowColor:  widget.style?.shadowColor ?? NUIColors.NUIShadowBlack,
          borderRadiusCircular: widget.style?.radius ?? 0,
          color: widget.style?.outlineColor ?? NUIColors.NUISkeletalGray
        ),
      );
    }
    else{
      return content;
    }
  }
}

==> nui_media-0.0.45.tar.gz: lib/ui/nui_imageview_picker.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_media/nui_media.dart';

typedef ImageSelectListener = void Function(NUIMediaFile file);

class NUIImageViewStyle{
  NUIImageViewStyle({this.elevation, this.shadowColor, this.outlineThickness, this.outlineColor, this.backgroundColor, this.radius, this.placeHolder, this.errorHolder, this.fit, this.rippleColor});
  double elevation;
  Color shadowColor;
  double outlineThickness;
  Color outlineColor;
  double radius;
  Color backgroundColor;
  Color rippleColor;
  Widget placeHolder;
  Widget errorHolder;
  BoxFit fit = BoxFit.cover;

}

class NUIImageViewPicker extends StatefulWidget {
  NUIImageViewPicker({this.path, @required this.width, @required this.height, this.isLocal:true, this.style, this.selectionOption: NUIMediaSelectionOption.GALLERY, this.enabled: true, this.listener, Key key}): super(key: key);
  final String path;
  final bool isLocal;
  final double width;
  final double height;
  final bool enabled;
  final NUIMediaSelectionOption selectionOption;
  final NUIImageViewStyle style;
  final ImageSelectListener listener;
  @override
  _NUIImageViewPickerState createState() => _NUIImageViewPickerState();
}

class _NUIImageViewPickerState extends State<NUIImageViewPicker> {
  String imagePath;
  NUIMediaFile imageFile;

  @override
  void initState(){
    super.initState();
    this.imagePath = widget.path;
  }

  double _getInnerHeight(){
    return widget.height - ((widget.style?.outlineThickness ?? 0)*2);
  }

  double _getInnerWidth(){
    return widget.width - ((widget.style?.outlineThickness ?? 0)*2);
  }

  Widget _getDefaultPlaceHolder(){
    return Center(
        child: Padding(
          padding: const EdgeInsets.all(5.0),
          child: Text("Click here", style: TextStyle(color: NUIColors.NUITextGray, fontSize: 12), textAlign: TextAlign.center),
        )
    );
  }

  Widget _getImageView(){
    if(isNullOrEmpty(imagePath) && imageFile == null){
      return widget.style?.placeHolder ?? _getDefaultPlaceHolder();
    }
    else{
      if(widget.isLocal || imageFile != null){
        return loadImageLocal(imageFile?.path ?? widget.path, _getInnerWidth(), _getInnerHeight());
      }
      else{
        return loadImage(widget.path, width: _getInnerWidth(), height: _getInnerHeight());
      }
    }
  }

  void selectImage(){
    if(!widget.enabled) return;

    NUIBottomSheet dialog;
    dialog = NUIMediaUtil.showMediaSelection(context, enableGallery: widget.selectionOption == NUIMediaSelectionOption.GALLERY || widget.selectionOption == NUIMediaSelectionOption.BOTH, enableCamera: widget.selectionOption == NUIMediaSelectionOption.CAMERA || widget.selectionOption == NUIMediaSelectionOption.BOTH, enableRecord: false, listener: (files){
      if(!isNullOrEmpty(files)){
        //An image has been selected either via camera or gallery
        setState(() {
          this.imageFile = files[0];
          if(widget.listener != null){
            widget.listener(this.imageFile);
            dialog.dismiss((){
            });
          }
        });
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    Widget content = NUIClipView(
      borderRadius: BorderRadius.circular(widget.style?.radius ?? 10),
      child: Container(
        height: _getInnerHeight(),
        width: _getInnerWidth(),
        color: widget.style?.backgroundColor ?? NUIColors.NUISkeletalLightGray,
        child: NUIRippleContainer(
          child: _getImageView(),
          radius: widget.style.radius ?? 10,
          borderRadius: BorderRadius.circular(widget.style?.radius ?? 10),
          normalColor: NUIColors.NUITransparent,
          rippleColor: widget.enabled ? (widget.style?.rippleColor ?? NUIColors.NUIBlack.withOpacity(0.2)) : NUIColors.NUITransparent,
          onTap: (){
            selectImage();
          },
        ),
      ),
    );

    if(widget.style?.outlineThickness != null && widget.style.outlineThickness > 0){
      return Container(
        height: widget.height,
        width: widget.width,
        alignment: Alignment.center,
        child: content,
        decoration: NUIBoxDecoration(
          shadowRadius: widget.style?.elevation ?? 0,
          shadowColor:  widget.style?.shadowColor ?? NUIColors.NUIShadowBlack,
          borderRadiusCircular: widget.style?.radius ?? 0,
          color: widget.style?.outlineColor ?? NUIColors.NUISkeletalGray
        ),
      );
    }
    else{
      return content;
    }
  }
}
